@@ -66,7 +66,7 @@ public:
 		SFlags flags = Style_Default,
 		const TQStyleOption &opt = TQStyleOption::Default ) const;
 
-	void drawControl( TQ_ControlElement element,
+	void drawControl( ControlElement element,
 		TQPainter *p,
 		const TQStyleControlElementData &ceData,
 		ControlElementFlags elementFlags,
@@ -76,7 +76,7 @@ public:
 		const TQStyleOption& = TQStyleOption::Default,
 		const TQWidget *widget = 0 ) const;
 
-	void drawControlMask( TQ_ControlElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQStyleOption &, const TQWidget * = 0) const;
+	void drawControlMask( ControlElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQStyleOption &, const TQWidget * = 0) const;
 
 	void drawComplexControl( ComplexControl control,
 		TQPainter *p,
