@@ -529,7 +529,7 @@ void GlowClient::showEvent( TQShowEvent * )
 
 void GlowClient::mouseDoubleClickEvent( TQMouseEvent *e )
 {
-	if(e->button() == Qt::LeftButton && _title_spacer->geometry().contains(e->pos()))
+	if(e->button() == TQt::LeftButton && _title_spacer->geometry().contains(e->pos()))
 		titlebarDblClickOperation();
 }
 
@@ -652,33 +652,33 @@ void GlowClient::createButtons()
 	TQSize size = globals->theme()->buttonSize;
 
 	m_stickyButton = factory->createGlowButton(widget(),
-					"StickyButton", isOnAllDesktops()?i18n("Not on all desktops"):i18n("On all desktops"), Qt::LeftButton|Qt::RightButton);
+					"StickyButton", isOnAllDesktops()?i18n("Not on all desktops"):i18n("On all desktops"), TQt::LeftButton|TQt::RightButton);
 	m_stickyButton->setFixedSize(size);
-	connect(m_stickyButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(toggleOnAllDesktops()));
+	connect(m_stickyButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(toggleOnAllDesktops()));
 	m_buttonList.insert(m_buttonList.end(), m_stickyButton);
 
 	m_helpButton = factory->createGlowButton(widget(),
 					"HelpButton", i18n("Help"));
 	m_helpButton->setFixedSize(size);
-	connect(m_helpButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(showContextHelp()));
+	connect(m_helpButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(showContextHelp()));
 	m_buttonList.insert(m_buttonList.end(), m_helpButton);
 
 	m_minimizeButton = factory->createGlowButton(widget(),
 					"IconifyButton", i18n("Minimize"));
 	m_minimizeButton->setFixedSize(size);
-	connect(m_minimizeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(minimize()));
+	connect(m_minimizeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(minimize()));
 	m_buttonList.insert(m_buttonList.end(), m_minimizeButton);
 
 	m_maximizeButton=factory->createGlowButton(widget(),
-					"MaximizeButton", i18n("Maximize"), Qt::LeftButton|Qt::MidButton|Qt::RightButton);
+					"MaximizeButton", i18n("Maximize"), TQt::LeftButton|TQt::MidButton|TQt::RightButton);
 	m_maximizeButton->setFixedSize(size);
-	connect(m_maximizeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotMaximize()));
+	connect(m_maximizeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotMaximize()));
 	m_buttonList.insert(m_buttonList.end(), m_maximizeButton);
 
 	m_closeButton = factory->createGlowButton(widget(),
 					"CloseButton", i18n("Close"));
 	m_closeButton->setFixedSize(size);
-	connect(m_closeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(closeWindow()));
+	connect(m_closeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(closeWindow()));
 	m_buttonList.insert(m_buttonList.end(), m_closeButton);
 }
 
@@ -860,27 +860,27 @@ void GlowClient::slotMaximize()
 
 bool GlowClient::eventFilter( TQObject* o, TQEvent* e )
 {
-	if( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget()))
+	if( o != widget())
 		return false;
 	switch( e->type())
 	{
 	case TQEvent::Resize:
-	    resizeEvent( TQT_TQRESIZEEVENT( e ));
+	    resizeEvent( static_cast<TQResizeEvent*>( e ));
 	    return true;
 	case TQEvent::Paint:
-	    paintEvent( TQT_TQPAINTEVENT( e ));
+	    paintEvent( static_cast<TQPaintEvent*>( e ));
 	    return true;
 	case TQEvent::MouseButtonDblClick:
-	    mouseDoubleClickEvent( TQT_TQMOUSEEVENT( e ));
+	    mouseDoubleClickEvent( static_cast<TQMouseEvent*>( e ));
 	    return true;
 	case TQEvent::MouseButtonPress:
-	    processMousePressEvent( TQT_TQMOUSEEVENT( e ));
+	    processMousePressEvent( static_cast<TQMouseEvent*>( e ));
 	    return true;
 	case TQEvent::Show:
-	    showEvent( TQT_TQSHOWEVENT( e ));
+	    showEvent( static_cast<TQShowEvent*>( e ));
 	    return true;
 	case TQEvent::Wheel:
-	    wheelEvent( TQT_TQWHEELEVENT( e ));
+	    wheelEvent( static_cast<TQWheelEvent*>( e ));
 	    return true;
 	default:
 	    break;
