@@ -388,8 +388,8 @@ void ThemeHandler::initTheme()
 	setPixmap( frameTR, "frame", "TR.xpm" );
 
 	// Sides
-	setPixmap( frameL, "frame", "L.xpm", true,Qt::Vertical );
-	setPixmap( frameR, "frame", "R.xpm", true,Qt::Vertical );
+	setPixmap( frameL, "frame", "L.xpm", true,TQt::Vertical );
+	setPixmap( frameR, "frame", "R.xpm", true,TQt::Vertical );
 
 	// Bottom
 	setPixmap( frameBL, "frame", "BL.xpm" );
@@ -843,7 +843,7 @@ void IceWMButton::mousePressEvent( TQMouseEvent* e )
 {
 	last_button = e->button();
 	TQMouseEvent me ( e->type(), e->pos(), e->globalPos(),
-					 (e->button()&m_realizeButtons)?Qt::LeftButton:Qt::NoButton, e->state() );
+					 (e->button()&m_realizeButtons)?TQt::LeftButton:TQt::NoButton, e->state() );
 	TQButton::mousePressEvent( &me );
 }
 
@@ -852,7 +852,7 @@ void IceWMButton::mouseReleaseEvent( TQMouseEvent* e )
 {
 	last_button = e->button();
 	TQMouseEvent me ( e->type(), e->pos(), e->globalPos(),
-					 (e->button()&m_realizeButtons)?Qt::LeftButton:Qt::NoButton, e->state() );
+					 (e->button()&m_realizeButtons)?TQt::LeftButton:TQt::NoButton, e->state() );
 	TQButton::mouseReleaseEvent( &me );
 }
 
@@ -976,16 +976,16 @@ void IceWMClient::addClientButtons( const TQString& s )
 						if (showMenuButtonIcon) {
 							renderMenuIcons();
 							button[BtnSysMenu] = new IceWMButton(this, "menu",
-								&menuButtonWithIconPix, false, i18n("Menu"), Qt::LeftButton|Qt::RightButton);
+								&menuButtonWithIconPix, false, i18n("Menu"), TQt::LeftButton|TQt::RightButton);
 						}
 						else
 							button[BtnSysMenu] = new IceWMButton(this, "menu",
 								&menuButtonPix, false, i18n("Menu"));
 
-						connect( button[BtnSysMenu], TQT_SIGNAL(pressed()),
-								 this, TQT_SLOT(menuButtonPressed()));
-						connect( button[BtnSysMenu], TQT_SIGNAL(released()),
-								 this, TQT_SLOT(menuButtonReleased()));
+						connect( button[BtnSysMenu], TQ_SIGNAL(pressed()),
+								 this, TQ_SLOT(menuButtonPressed()));
+						connect( button[BtnSysMenu], TQ_SIGNAL(released()),
+								 this, TQ_SLOT(menuButtonReleased()));
 						hb->addWidget( button[BtnSysMenu] );
 					}
 					break;
@@ -996,8 +996,8 @@ void IceWMClient::addClientButtons( const TQString& s )
 						button[BtnClose] = new IceWMButton(this, "close",
 								&closePix, false, i18n("Close"));
 						hb->addWidget( button[BtnClose] );
-						connect( button[BtnClose], TQT_SIGNAL(clicked()),
-								 this, TQT_SLOT(closeWindow()));
+						connect( button[BtnClose], TQ_SIGNAL(clicked()),
+								 this, TQ_SLOT(closeWindow()));
 					}
 					break;
 
@@ -1005,10 +1005,10 @@ void IceWMClient::addClientButtons( const TQString& s )
 					if ( validPixmaps(maximizePix) && !button[BtnMaximize] && isMaximizable() )
 					{
 						button[BtnMaximize] = new IceWMButton(this, "maximize",
-								&maximizePix, false, i18n("Maximize"), Qt::LeftButton|Qt::MidButton|Qt::RightButton);
+								&maximizePix, false, i18n("Maximize"), TQt::LeftButton|TQt::MidButton|TQt::RightButton);
 						hb->addWidget( button[BtnMaximize] );
-						connect( button[BtnMaximize], TQT_SIGNAL(clicked()),
-								 this, TQT_SLOT(slotMaximize()));
+						connect( button[BtnMaximize], TQ_SIGNAL(clicked()),
+								 this, TQ_SLOT(slotMaximize()));
 					}
 					break;
 
@@ -1019,8 +1019,8 @@ void IceWMClient::addClientButtons( const TQString& s )
 						button[BtnMinimize] = new IceWMButton(this, "minimize",
 								&minimizePix, false, i18n("Minimize"));
 						hb->addWidget( button[BtnMinimize] );
-						connect( button[BtnMinimize], TQT_SIGNAL(clicked()),
-								 this, TQT_SLOT(minimize()));
+						connect( button[BtnMinimize], TQ_SIGNAL(clicked()),
+								 this, TQ_SLOT(minimize()));
 					}
 					break;
 
@@ -1038,8 +1038,8 @@ void IceWMClient::addClientButtons( const TQString& s )
 							isSetShade() ? &rolldownPix : &rollupPix,
 										    false, i18n("Rollup"));
 						hb->addWidget( button[BtnRollup] );
-						connect( button[BtnRollup], TQT_SIGNAL(clicked()),
-								 this, TQT_SLOT(toggleShade()));
+						connect( button[BtnRollup], TQ_SIGNAL(clicked()),
+								 this, TQ_SLOT(toggleShade()));
 					}
 					break;
 
@@ -1051,8 +1051,8 @@ void IceWMClient::addClientButtons( const TQString& s )
 								&depthPix, true, isOnAllDesktops()?i18n("Not on all desktops"):i18n("On all desktops"));
 						button[BtnDepth]->turnOn( isOnAllDesktops() );
 						hb->addWidget( button[BtnDepth] );
-						connect( button[BtnDepth], TQT_SIGNAL(clicked()),
-								 this, TQT_SLOT(toggleOnAllDesktops()));
+						connect( button[BtnDepth], TQ_SIGNAL(clicked()),
+								 this, TQ_SLOT(toggleOnAllDesktops()));
 					}
 					break;
 			}
@@ -1456,7 +1456,7 @@ void IceWMClient::showEvent(TQShowEvent *ev)
 
 void IceWMClient::mouseDoubleClickEvent( TQMouseEvent * e )
 {
-	if( e->button() != Qt::LeftButton )
+	if( e->button() != TQt::LeftButton )
 		return;
 
 	TQRect r;
@@ -1664,24 +1664,24 @@ void IceWMClient::menuButtonReleased()
 
 bool IceWMClient::eventFilter( TQObject* o, TQEvent* e )
 {
-	if( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget()))
+	if( o != widget())
 	return false;
 	switch( e->type())
 	{
 	case TQEvent::Resize:
-		resizeEvent(TQT_TQRESIZEEVENT( e ) );
+		resizeEvent(static_cast<TQResizeEvent*>( e ) );
 		return true;
 	case TQEvent::Paint:
-		paintEvent(TQT_TQPAINTEVENT( e ) );
+		paintEvent(static_cast<TQPaintEvent*>( e ) );
 		return true;
 	case TQEvent::MouseButtonDblClick:
-		mouseDoubleClickEvent(TQT_TQMOUSEEVENT( e ) );
+		mouseDoubleClickEvent(static_cast<TQMouseEvent*>( e ) );
 		return true;
 	case TQEvent::MouseButtonPress:
-		processMousePressEvent(TQT_TQMOUSEEVENT( e ) );
+		processMousePressEvent(static_cast<TQMouseEvent*>( e ) );
 		return true;
 	case TQEvent::Wheel:
-		wheelEvent( TQT_TQWHEELEVENT( e ));
+		wheelEvent( static_cast<TQWheelEvent*>( e ));
 		return true;
 	default:
 		break;
