@@ -312,7 +312,7 @@ void StdClient::addButtons(TQBoxLayout *hb, const TQString& s)
                           button[ButtonMenu]->setIconSet(isActive() ? *menu_pix : *dis_menu_pix);
                       else
                           button[ButtonMenu]->setIconSet( icon().pixmap( TQIconSet::Small, TQIconSet::Normal ));
-                      connect( button[0], TQT_SIGNAL( pressed() ), this, TQT_SLOT( menuButtonPressed() ) );
+                      connect( button[0], TQ_SIGNAL( pressed() ), this, TQ_SLOT( menuButtonPressed() ) );
                       hb->addWidget(button[ButtonMenu]);
                   }
                   break;
@@ -325,7 +325,7 @@ void StdClient::addButtons(TQBoxLayout *hb, const TQString& s)
                      button[ButtonSticky]->setCursor(ArrowCursor);
                      button[ButtonSticky]->setIconSet(isOnAllDesktops() ? isActive() ? *pindown_pix : *dis_pindown_pix :
                                                       isActive() ? *pinup_pix : *dis_pinup_pix );
-                     connect( button[ButtonSticky], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( toggleOnAllDesktops() ) ) );
+                     connect( button[ButtonSticky], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( toggleOnAllDesktops() ) ) );
                      hb->addWidget(button[ButtonSticky]);
                   }
                   break;
@@ -335,7 +335,7 @@ void StdClient::addButtons(TQBoxLayout *hb, const TQString& s)
                       button[ButtonHelp] = new TQToolButton( widget(), 0 );
                       TQToolTip::add( button[ButtonHelp], i18n("Help") );
                       button[ButtonHelp]->setIconSet( isActive() ? *question_mark_pix : *dis_question_mark_pix);
-                      connect( button[ButtonHelp], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( showContextHelp() ) ) );
+                      connect( button[ButtonHelp], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( showContextHelp() ) ) );
                       button[ButtonHelp]->setCursor(ArrowCursor);
                       hb->addWidget(button[ButtonHelp]);
                   }
@@ -347,7 +347,7 @@ void StdClient::addButtons(TQBoxLayout *hb, const TQString& s)
                       TQToolTip::add( button[ButtonMinimize], i18n("Minimize") );
                       button[ButtonMinimize]->setCursor(ArrowCursor);
                       button[ButtonMinimize]->setIconSet(isActive() ? *minimize_pix : *dis_minimize_pix);
-                      connect( button[ButtonMinimize], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( minimize() ) ) );
+                      connect( button[ButtonMinimize], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( minimize() ) ) );
                       hb->addWidget(button[ButtonMinimize]);
                   }
                   break;
@@ -359,8 +359,8 @@ void StdClient::addButtons(TQBoxLayout *hb, const TQString& s)
                       TQToolTip::add( button[ButtonMaximize], max?i18n("Restore"):i18n("Maximize") );
                       button[ButtonMaximize]->setCursor(ArrowCursor);
                       button[ButtonMaximize]->setIconSet( max?(isActive() ? *normalize_pix : *dis_normalize_pix):(isActive() ? *maximize_pix : *dis_maximize_pix) );
-                      connect( button[ButtonMaximize], TQT_SIGNAL( clicked(ButtonState) ),
-                               this, ( TQT_SLOT( maxButtonClicked(ButtonState) ) ) );
+                      connect( button[ButtonMaximize], TQ_SIGNAL( clicked(ButtonState) ),
+                               this, ( TQ_SLOT( maxButtonClicked(ButtonState) ) ) );
                       hb->addWidget(button[ButtonMaximize]);
                   }
                   break;
@@ -371,7 +371,7 @@ void StdClient::addButtons(TQBoxLayout *hb, const TQString& s)
                       TQToolTip::add( button[ButtonClose], i18n("Close") );
                       button[ButtonClose]->setCursor(ArrowCursor);
                       button[ButtonClose]->setIconSet(isActive() ? *close_pix : *dis_close_pix);
-                      connect( button[ButtonClose], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( closeWindow() ) ) );
+                      connect( button[ButtonClose], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( closeWindow() ) ) );
                       hb->addWidget(button[ButtonClose]);
                   }
                   break;
@@ -495,7 +495,7 @@ void StdClient::paintEvent( TQPaintEvent* )
 
 void StdClient::mouseDoubleClickEvent( TQMouseEvent * e )
 {
-    if ( e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == TQt::LeftButton && titlebar->geometry().contains( e->pos() ) )
 	titlebarDblClickOperation();
 }
 
@@ -549,23 +549,23 @@ bool StdClient::eventFilter( TQObject* o, TQEvent* e )
 
     switch ( e->type() ) {
     case TQEvent::Resize:
-	resizeEvent( TQT_TQRESIZEEVENT( e ) );
+	resizeEvent( static_cast<TQResizeEvent*>( e ) );
 	return true;
 
     case TQEvent::Paint:
-	paintEvent( TQT_TQPAINTEVENT( e ) );
+	paintEvent( static_cast<TQPaintEvent*>( e ) );
 	return true;
 
     case TQEvent::MouseButtonDblClick:
-	mouseDoubleClickEvent( TQT_TQMOUSEEVENT( e ) );
+	mouseDoubleClickEvent( static_cast<TQMouseEvent*>( e ) );
 	return true;
 
     case TQEvent::MouseButtonPress:
-	processMousePressEvent( TQT_TQMOUSEEVENT( e ) );
+	processMousePressEvent( static_cast<TQMouseEvent*>( e ) );
 	return true;
 
     case TQEvent::Wheel:
-	wheelEvent( TQT_TQWHEELEVENT( e ));
+	wheelEvent( static_cast<TQWheelEvent*>( e ));
 	return true;
 
     default:
@@ -615,7 +615,7 @@ void StdToolClient::init()
 
     closeBtn = new TQToolButton( widget(), 0 );
     TQToolTip::add( closeBtn, i18n("Close") );
-    connect( closeBtn, TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( closeWindow() ) ) );
+    connect( closeBtn, TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( closeWindow() ) ) );
     closeBtn->setFixedSize( 13, 13);
     reset( -1U );
 
@@ -666,7 +666,7 @@ void StdToolClient::paintEvent( TQPaintEvent* )
 
 void StdToolClient::mouseDoubleClickEvent( TQMouseEvent * e )
 {
-    if ( e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
+    if ( e->button() == TQt::LeftButton && titlebar->geometry().contains( e->pos() ) )
         titlebarDblClickOperation();
 }
 
@@ -698,23 +698,23 @@ bool StdToolClient::eventFilter( TQObject* o, TQEvent* e )
 
     switch ( e->type() ) {
     case TQEvent::Resize:
-	resizeEvent( TQT_TQRESIZEEVENT( e ) );
+	resizeEvent( static_cast<TQResizeEvent*>( e ) );
 	return true;
 
     case TQEvent::Paint:
-	paintEvent( TQT_TQPAINTEVENT( e ) );
+	paintEvent( static_cast<TQPaintEvent*>( e ) );
 	return true;
 
     case TQEvent::MouseButtonDblClick:
-	mouseDoubleClickEvent( TQT_TQMOUSEEVENT( e ) );
+	mouseDoubleClickEvent( static_cast<TQMouseEvent*>( e ) );
 	return true;
 
     case TQEvent::MouseButtonPress:
-	processMousePressEvent( TQT_TQMOUSEEVENT( e ) );
+	processMousePressEvent( static_cast<TQMouseEvent*>( e ) );
 	return true;
 
     case TQEvent::Wheel:
-	wheelEvent( TQT_TQWHEELEVENT( e ));
+	wheelEvent( static_cast<TQWheelEvent*>( e ));
 	return true;
 
     default:
