@@ -118,18 +118,18 @@ static void create_pixmaps()
                                 hColor.light(150),
                                 hColor.dark(150),
                                 KPixmapEffect::DiagonalGradient);
-        bitBlt(TQT_TQPAINTDEVICE(&aPix), 1, 1, TQT_TQPAINTDEVICE(&aInternal), 0, 0, 8, 8, TQt::CopyROP, true);
-        bitBlt(TQT_TQPAINTDEVICE(&iPix), 1, 1, TQT_TQPAINTDEVICE(&iInternal), 0, 0, 8, 8, TQt::CopyROP, true);
+        bitBlt(&aPix, 1, 1, &aInternal, 0, 0, 8, 8, TQt::CopyROP, true);
+        bitBlt(&iPix, 1, 1, &iInternal, 0, 0, 8, 8, TQt::CopyROP, true);
 
         // normal buttons
         btnPix = new KPixmap;
         btnPix->resize(14, 14);
-        bitBlt(TQT_TQPAINTDEVICE(btnPix), 2, 2, TQT_TQPAINTDEVICE(&aPix), 0, 0, 10, 10, TQt::CopyROP, true);
+        bitBlt(btnPix, 2, 2, &aPix, 0, 0, 10, 10, TQt::CopyROP, true);
         drawButtonFrame(btnPix, KDecoration::options()->colorGroup(KDecorationOptions::ColorFrame, true));
 
         iBtnPix = new KPixmap;
         iBtnPix->resize(14, 14);
-        bitBlt(TQT_TQPAINTDEVICE(iBtnPix), 2, 2, TQT_TQPAINTDEVICE(&iPix), 0, 0, 10, 10, TQt::CopyROP, true);
+        bitBlt(iBtnPix, 2, 2, &iPix, 0, 0, 10, 10, TQt::CopyROP, true);
         drawButtonFrame(iBtnPix, KDecoration::options()->colorGroup(KDecorationOptions::ColorFrame, false));
 
 
@@ -153,18 +153,18 @@ static void create_pixmaps()
                                 hColor.light(150),
                                 hColor.dark(150),
                                 KPixmapEffect::DiagonalGradient);
-        bitBlt(TQT_TQPAINTDEVICE(&aPix), 1, 1, TQT_TQPAINTDEVICE(&aInternal), 0, 0, 8, 8, TQt::CopyROP, true);
-        bitBlt(TQT_TQPAINTDEVICE(&iPix), 1, 1, TQT_TQPAINTDEVICE(&iInternal), 0, 0, 8, 8, TQt::CopyROP, true);
+        bitBlt(&aPix, 1, 1, &aInternal, 0, 0, 8, 8, TQt::CopyROP, true);
+        bitBlt(&iPix, 1, 1, &iInternal, 0, 0, 8, 8, TQt::CopyROP, true);
 
         btnPixDown = new KPixmap;
         btnPixDown->resize(14, 14);
-        bitBlt(TQT_TQPAINTDEVICE(btnPixDown), 2, 2, TQT_TQPAINTDEVICE(&aPix), 0, 0, 10, 10, TQt::CopyROP, true);
+        bitBlt(btnPixDown, 2, 2, &aPix, 0, 0, 10, 10, TQt::CopyROP, true);
         drawButtonFrame(btnPixDown, KDecoration::options()->colorGroup(KDecorationOptions::ColorFrame,
                                                         true));
 
         iBtnPixDown = new KPixmap;
         iBtnPixDown->resize(14, 14);
-        bitBlt(TQT_TQPAINTDEVICE(iBtnPixDown), 2, 2, TQT_TQPAINTDEVICE(&iPix), 0, 0, 10, 10, TQt::CopyROP, true);
+        bitBlt(iBtnPixDown, 2, 2, &iPix, 0, 0, 10, 10, TQt::CopyROP, true);
         drawButtonFrame(iBtnPixDown, KDecoration::options()->colorGroup(KDecorationOptions::ColorFrame,
                                                          false));
     }
@@ -272,14 +272,14 @@ void SystemButton::drawButton(TQPainter *p)
 void SystemButton::mousePressEvent( TQMouseEvent* e )
 {
    last_button = e->button();
-   TQMouseEvent me ( e->type(), e->pos(), e->globalPos(), Qt::LeftButton, e->state() );
+   TQMouseEvent me ( e->type(), e->pos(), e->globalPos(), TQt::LeftButton, e->state() );
    TQButton::mousePressEvent( &me );
 }
 
 void SystemButton::mouseReleaseEvent( TQMouseEvent* e )
 {
    last_button = e->button();
-   TQMouseEvent me ( e->type(), e->pos(), e->globalPos(), Qt::LeftButton, e->state() );
+   TQMouseEvent me ( e->type(), e->pos(), e->globalPos(), TQt::LeftButton, e->state() );
    TQButton::mouseReleaseEvent( &me );
 }
 
@@ -351,7 +351,7 @@ void SystemClient::addButtons(TQBoxLayout *hb, const TQString& s)
               case 'X': // Close button
                   if ((!button[ButtonClose]) && isCloseable()) {
                       button[ButtonClose] = new SystemButton(this, "close", NULL, i18n("Close"));
-                      connect( button[ButtonClose], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( closeWindow() ) ) );
+                      connect( button[ButtonClose], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( closeWindow() ) ) );
                       hb->addWidget(button[ButtonClose]);
                       hb->addSpacing(1);
                   }
@@ -364,7 +364,7 @@ void SystemClient::addButtons(TQBoxLayout *hb, const TQString& s)
                          button[ButtonSticky]->setBitmap(unsticky_bits);
                      else
                          button[ButtonSticky]->setBitmap(sticky_bits);
-                     connect( button[ButtonSticky], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( toggleOnAllDesktops() ) ) );
+                     connect( button[ButtonSticky], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( toggleOnAllDesktops() ) ) );
                      hb->addWidget(button[ButtonSticky]);
                      hb->addSpacing(1);
                   }
@@ -373,7 +373,7 @@ void SystemClient::addButtons(TQBoxLayout *hb, const TQString& s)
               case 'I': // Minimize button
                   if ((!button[ButtonMinimize]) && isMinimizable())  {
                       button[ButtonMinimize] = new SystemButton(this, "iconify", iconify_bits, i18n("Minimize"));
-                      connect( button[ButtonMinimize], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( minimize() ) ) );
+                      connect( button[ButtonMinimize], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( minimize() ) ) );
                       hb->addWidget(button[ButtonMinimize]);
                       hb->addSpacing(1);
                   }
@@ -390,7 +390,7 @@ void SystemClient::addButtons(TQBoxLayout *hb, const TQString& s)
                       }
                       else
                           button[ButtonMaximize] = new SystemButton(this, "maximize", maximize_bits, i18n("Maximize"));
-                      connect( button[ButtonMaximize], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( maxButtonClicked() ) ) );
+                      connect( button[ButtonMaximize], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( maxButtonClicked() ) ) );
                       hb->addWidget(button[ButtonMaximize]);
                       hb->addSpacing(1);
                   }
@@ -399,7 +399,7 @@ void SystemClient::addButtons(TQBoxLayout *hb, const TQString& s)
               case 'H': // Help button
                   if ((!button[ButtonHelp]) && providesContextHelp()) {
                       button[ButtonHelp] = new SystemButton(this, "help", question_bits, i18n("Help"));
-                      connect( button[ButtonHelp], TQT_SIGNAL( clicked() ), this, ( TQT_SLOT( showContextHelp() ) ) );
+                      connect( button[ButtonHelp], TQ_SIGNAL( clicked() ), this, ( TQ_SLOT( showContextHelp() ) ) );
                       hb->addWidget(button[ButtonHelp]);
                       hb->addSpacing(1);
                   }
@@ -412,24 +412,24 @@ void SystemClient::addButtons(TQBoxLayout *hb, const TQString& s)
 
 bool SystemClient::eventFilter( TQObject* o, TQEvent* e )
 {
-    if( TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(widget()))
+    if( o != widget())
        return false;
     switch( e->type())
     {
     case TQEvent::Resize:
-       resizeEvent(TQT_TQRESIZEEVENT( e ) );
+       resizeEvent(static_cast<TQResizeEvent*>( e ) );
        return true;
     case TQEvent::Paint:
-       paintEvent(TQT_TQPAINTEVENT( e ) );
+       paintEvent(static_cast<TQPaintEvent*>( e ) );
        return true;
     case TQEvent::MouseButtonDblClick:
-       mouseDoubleClickEvent(TQT_TQMOUSEEVENT( e ) );
+       mouseDoubleClickEvent(static_cast<TQMouseEvent*>( e ) );
        return true;
     case TQEvent::MouseButtonPress:
-       processMousePressEvent(TQT_TQMOUSEEVENT( e ) );
+       processMousePressEvent(static_cast<TQMouseEvent*>( e ) );
        return true;
     case TQEvent::Wheel:
-       wheelEvent( TQT_TQWHEELEVENT( e ));
+       wheelEvent( static_cast<TQWheelEvent*>( e ));
        return true;
     default:
         break;
@@ -608,7 +608,7 @@ void SystemClient::showEvent(TQShowEvent *)
 
 void SystemClient::mouseDoubleClickEvent( TQMouseEvent * e )
 {
-   if ( e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
+   if ( e->button() == TQt::LeftButton && titlebar->geometry().contains( e->pos() ) )
       titlebarDblClickOperation();
 }
 
